pub struct I24WithZeroedBits<const LOW_ZEROED_BITS: u8>(/* private fields */);Expand description
New type for signed integers that stores 32-bit numbers with LOW_ZEROED_BITS low bits zeroed
and truncated to 24-bits
Implementations
Sourceimpl<const LOW_ZEROED_BITS: u8> I24WithZeroedBits<LOW_ZEROED_BITS>
impl<const LOW_ZEROED_BITS: u8> I24WithZeroedBits<LOW_ZEROED_BITS>
Sourcepub const fn from_i32(v_original: i32) -> Self
pub const fn from_i32(v_original: i32) -> Self
Create a new I24WithZeroedBits from a signed 32-bit integer.
The input value is shifted right arithmetically by LOW_ZEROED_BITS before being stored.
When converted back with Self::to_i32, the value is shifted back with low bits being
zero.